#
# spec file for package qpdfview
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pver 0.5

Name:           qpdfview
Version:        0.5.0
Release:        3.1
Summary:        Tabbed document viewer in Qt
License:        GPL-2.0-or-later
Group:          Productivity/Office/Other
URL:            https://launchpad.net/qpdfview
Source:         %{url}/trunk/%{version}/+download/%{name}-%{pver}.tar.gz
Source1:        %{url}/trunk/%{version}/+download/%{name}-%{pver}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Sql)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
%if 0%{?suse_version} >= 1699
BuildRequires:  pkgconfig(cups)
%else
BuildRequires:  cups-devel
%endif
BuildRequires:  pkgconfig(ddjvuapi)
BuildRequires:  pkgconfig(libspectre)
BuildRequires:  pkgconfig(poppler-qt6)
BuildRequires:  pkgconfig(synctex)
BuildRequires:  pkgconfig(zlib)
Requires:       %{name}-plugin-pdf
Requires:       qt6-sql-sqlite
Recommends:     %{name}-lang
Suggests:       %{name}-plugin-djvu
Suggests:       %{name}-plugin-image
Suggests:       %{name}-plugin-ps

%description
qpdfview uses Poppler for PDF support, libspectre for PS support,
DjVuLibre for DjVu support, CUPS for printing support and the Qt
toolkit for its interface.

Current features include:
 * Outline, properties and thumbnail panes.
 * Scale, rotate and fit.
 * Fullscreen and presentation views.
 * Continuous and multiple-page layouts.
 * Search for text.
 * Configurable tool bars.
 * Configurable keyboard shortcuts.
 * Persistent per-file settings.
 * SyncTeX support.
 * Rudimentary annotation support.
 * Rudimentary form support.
 * Support for PostScript and DjVu documents.

%package plugin-djvu
Summary:        qpdfview plugin: DjVu documents
Group:          Productivity/Office/Other
Requires:       %{name}

%description plugin-djvu
This plugin is required to read DjVu documents
(*.djvu files) with the qpdfview document viewer.

%package plugin-image
Summary:        qpdfview plugin: Image files
Group:          Productivity/Office/Other
Requires:       %{name}

%description plugin-image
This plugin is required to read Image files
(*.tiff files) with the qpdfview document viewer.

%package plugin-pdf
Summary:        qpdfview plugin: PDF documents
Group:          Productivity/Office/Other
Requires:       %{name}

%description plugin-pdf
This plugin is required to read PDF documents
(*.pdf files) with the qpdfview document viewer.

%package plugin-ps
Summary:        qpdfview plugin: PostScript documents
Group:          Productivity/Office/Other
Requires:       %{name}

%description plugin-ps
This plugin is required to read PostScript documents
(*.ps files) with the qpdfview document viewer.

%lang_package

%prep
%autosetup -p1 -n %{name}-%{pver}

%build
%{_qt6_bindir}/lrelease %{name}.pro
%qmake6 %{name}.pro \
    PLUGIN_INSTALL_PATH=%{_libdir}/%{name}
%qmake6_build

%install
%qmake6_install
%fdupes %{buildroot}
%find_lang %{name} --with-qt

%files
%license COPYING
%doc CHANGES CONTRIBUTORS README TODO
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_datadir}/metainfo/%{name}.appdata.xml
%dir %{_datadir}/%{name}
%doc %{_datadir}/%{name}/help.html

%files plugin-djvu
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}_djvu.so

%files plugin-image
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}_image.so

%files plugin-pdf
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}_pdf.so

%files plugin-ps
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib%{name}_ps.so

%files lang -f %{name}.lang
%if 0%{?sle_version}
%{_datadir}/%{name}/%{name}_???.qm
%endif
%doc %{_datadir}/%{name}/help_*.html

%changelog
* Thu Apr 17 2025 Андрей Алыпов <and.november@opensuse.org>
- Build with Qt6
* Sun Jul 16 2023 munix9@googlemail.com
- Fix compilation build, use C++17
* Wed Mar  1 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.5.0:
  * Added support for Qt version 6 while keeping compatibility with
    Qt version 4 and 5 intact.
  * Changed required language version from C++98 to C++11.
  * Added context menu item to add selected text to bookmark comment.
  * Imported various new and updated translations from Launchpad.
- Remove qpdfview-qt5.15.patch
* Fri Jun 12 2020 Kyrill Detinov <lazy.kent@opensuse.org>
- Add qpdfview-qt5.15.patch: fix build with Qt 5.15.
* Thu Jul 25 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.4.18.
  * Fixed encoding issues w.r.t. CUPS names.
  * Fixed not overwriting page ranges CUPS option when set already
    by Qt's print dialog.
  * Fixed refreshing modified documents from disk.
  * Added support for nested splitting of document views.
  * Added support for transparent decompression of document files.
  * Added restoring of tab order and of current tab.
  * Added action to open current file in new window.
  * Updated support for MuPDF to version 1.12 and later.
  * Added support for EPUB, XPS, CBZ and FB2 via MuPDF.
  * Imported various new and updated translations.
- Changes in 0.4.17.
  * Fixed query to populate the instance list for the choose
    instance dialog.
  * Fixed selecting the complete text upon opening a page number
    dialog.
  * Fixed computation of tile sub rect w.r.t. non-unit device pixel
    ratios.
  * Moved loading of interactive elements out of the main event loop.
  * Optimize tile rendering event handling by centralizing dispatch.
  * The results of the current tab are now automatically expanded
    in the extended search dock.
  * Added support for external document links to the outline view.
  * Added optional page-parallel execution of text search.
  * Added triggering SyncTeX reverse search using a keyboard modifier.
  * Keyboard modifiers for mouse interaction can be disabled.
  * Optimizations of the search dock layout w.r.t.
    vertical/horizontal positioning.
  * Added context menu action to move document to a different
    instance.
  * Changed cache size tracking from byte to kilobyte granularity
    to support more than 2 GB cache.
  * Added a save in addition to the save-as action to simplify
    modifying documents in-place.
  * Added Japanese translations.
  * Updated British English, Russian, French, Lithunian
    translations.
* Thu Feb  7 2019 cfeck@kde.org
- Split plugins to separate packages. (bsc# 1122801)
- Removed obsolete Qt4 build.
- Run spec-cleaner.
* Fri Nov 20 2015 sor.alexei@meowr.ru
- Update to 0.4.16:
  * Fix an incompatibility with FDo's shared MIME type database
    that broke opening DjVu documents.
  * Add function to dynamically fit thumbnails into the viewport.
  * Add support to use system SyncTeX parser library.
  * Add support to open image formats supported by Qt.
  * SyncTeX is now available and discoverable with the main view's
    context menu.
  * Update Czech, Malay, Brazilian, Russian, Ukrainian, Portuguese,
    Lithunian, Spanish, and French translations.
* Sun Jun  7 2015 sor.alexei@meowr.ru
- Update to 0.4.15:
  * Fix compatibility with MuPDF version 1.7.
  * Add keeping the page-relative position upon page change.
  * Add document properties on PDF version, encryption and
    linearization.
  * Add keyboard navigation to the outline view.
  * Add configurable document and tab context menus.
  * Add composition modes to adjust the background of scanned
    documents.
  * Extend the default movement keyboard shortcuts to include the
    numpad keys.
  * Made the trim-margins setting a per-tab property.
  * Add Hungarian translation.
  * Update Polish, Italian, Czech, British English, Malay,
    Ukrainian, French translations.
* Sat May 23 2015 sor.alexei@meowr.ru
- Fix build with latest Qt5-related RPM macros.
- Add GPG signature.
- Add SQL backend requiring.
- Build with Qt4 for openSUSE 13.2 and older.
* Sun Feb 22 2015 sor.alexei@meowr.ru
- Update to 0.4.14:
  * Fix keyboard movement not working in annotations and form
    fields.
  * Fix display of warning dialog upon restoring tabs.
  * Fixed compilation using LLVM Clang.
  * Fixed crash upon middle-clicking into empty part of tab bar.
  * Fixed a race condition in text extraction within the extended search dock.
  * Fixed losing rendering hints after unlocking encrypted PDF documents.
  * Improve user interaction of the extended search dock.
  * Improve the speed of text extraction within the extended search
    dock.
  * Improve performance at very large scale factors by dynamically
    adjusting tile size.
  * Add restoring of expanded outline items after refresh.
  * Add various smaller user interface enhancements.
  * Add whole-words-only search option (depends on Poppler
    version 0.31 or higher).
  * Add optionally searchable tabs and bookmarks menus.
  * Improve flexibility of searching DjVu documents.
  * Add Finnish translation of online help.
  * Update settings section of the online help.
  * Update Czech, Ukrainian, Polish, British Englis, Slovak,
    Spanish, Simplified Chinese, Catalan, Russian, Galician,
    Malay, French translations.
* Tue Oct 21 2014 sor.alexei@meowr.ru
- Update to 0.4.13:
  * Fix a memory leak when processing meta-data in the DjVu
    plug-in.
  * Fix a crash when loading corrupted DjVu documents
  * Remove the dialog warning about unknown file type to fix the
    '--quiet' option.
  * Add optional extended search dock displaying results from all
    open tabs.
  * Add per-tab setting to convert pages to grayscale after
    rendering.
  * Update British English, Czech, Malay, Galician, Kazakh,
    Ukrainian, Portuguese, and Polish translations.
* Fri Oct 10 2014 sor.alexei@meowr.ru
- Initial build.
